==> haskell-servant-server-0.16.2-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.16.2
id: servant-server-0.16.2-AMa6qzrJWfV7NxoBUek5ar
key: servant-server-0.16.2-AMa6qzrJWfV7NxoBUek5ar
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 12bc658a8f118d04bc945f421b128a8a
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-server-0.16.2
hs-libraries: HSservant-server-0.16.2-AMa6qzrJWfV7NxoBUek5ar
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-api-data-0.4.1.1-B1LvsReVYs7Fz0hm5fLXfF
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    servant-0.16.2-197YfROujc2H2pUJUX0lCx
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-app-static-3.1.6.3-I67q4seRB6fE4t07lqJlNK
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.16.2-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.16.2
id: servant-server-0.16.2-8Thl2VLCBlF3qxyFC3vvMb
key: servant-server-0.16.2-8Thl2VLCBlF3qxyFC3vvMb
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: cd4d51f596f25d93f5749b4fdcb03433
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-server-0.16.2
hs-libraries: HSservant-server-0.16.2-8Thl2VLCBlF3qxyFC3vvMb
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-api-data-0.4.1.1-B1LvsReVYs7Fz0hm5fLXfF
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    servant-0.16.2-197YfROujc2H2pUJUX0lCx
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-app-static-3.1.6.3-6ZpbpRaUxULJuGdxVSQiK7
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
